import translate from '@/modules/translate/translate';
import {UserRoleCell, UserLangCell, UserStatusCell} from '@/pages/users/usersTab/_chunks/tableCells';

const TABLE_COLS = [
    {
        key: 'role',
        label: '',
        sortable: true,
        renderComponent: () => (UserRoleCell),
        tdClass: 'icon',
        thClass: 'role'
    },
    {
        key: 'registrations',
        label: '',
        sortable: true,
        renderComponent: () => (UserStatusCell),
        thClass: 'registrations'
    },
    {
        key: 'name',
        label: translate('aclpbx.userName'),
        sortable: true,
        thClass: 'name'
    },
    {
        key: 'login',
        label: translate('aclpbx.userPrincipalName'),
        sortable: true,
        thClass: 'login'
    },
    {
        key: 'extension',
        label: translate('aclpbx.extenNumber'),
        sortable: true,
        thClass: 'extension'
    },
    {
        key: 'faxNumber',
        label: translate('aclpbx.facsimileTelephoneNumber'),
        sortable: true,
        thClass: 'fax'
    },
    {
        key: 'officePhone',
        label: translate('aclpbx.officeNumber'),
        sortable: true,
        thClass: 'office'
    },
    {
        key: 'email',
        label: translate('aclpbx.Email'),
        sortable: true,
        thClass: 'email'
    },
    {
        key: 'mobilePhone',
        label: translate('aclpbx.MobileNumber'),
        sortable: true,
        thClass: 'mobile'
    },
    {
        key: 'dialplan',
        label: translate('aclpbx.userDialplan'),
        sortable: true,
        thClass: 'dialplan'
    },
    {
        key: 'faxDialplan',
        label: translate('aclpbx.userFaxDialplan'),
        sortable: true,
        thClass: 'faxDialplan'
    },
    {
        key: 'language',
        label: '',
        sortable: true,
        renderComponent: () => (UserLangCell),
        thClass: 'language',
        tdClass: 'language'
    },
    {
        key: 'groupName',
        label: translate('aclpbx.Group'),
        headerTitle: translate('aclpbx.Group'),
        sortable: true,
        thClass: 'group'
    },
    {
        key: 'department',
        label: translate('aclpbx.ou'),
        sortable: true,
        thClass: 'department'
    },
    {
        key: 'licenseType',
        label: translate('aclpbx.licenseType'),
        sortable: true,
        renderComponent: (data) => translate(`license.type.${data.value}`),
        thClass: 'license'
    },
    {
        key: 'pbx',
        label: 'PBX',
        sortable: true,
        requiresWmsNetwork: true,
        thClass: 'pbx'
    }
];

export const getColumns = (wmsNetwork) => {
    return TABLE_COLS.filter((column) => wmsNetwork || !column.requiresWmsNetwork);
};

export const USER_INITIAL = {
    role: 'user',
    name: '',
    login: '',
    extension: '',
    faxNumber: '',
    officePhone: '',
    email: '',
    mobilePhone: '',
    dialplan: 'users',
    faxDialplan: 'users',
    language: 'en',
    groupDn: '',
    department: '',
    licenseType: 'essential'
};

export const USER_ROLES = [
    {value: 'user', text: 'User'},
    {value: 'admin', text: 'Admin'},
    {value: 'fax', text: 'Fax'},
    {value: 'park_orbit', text: 'Park Orbit'},
    {value: 'room', text: 'Room'}
];

export const REMOVE_USERS_OPTIONS = [
    {text: translate('deleteUser.withoutData'), value: 'user', disabled: true},
    {text: translate('deleteUser.personalData'), value: 'personalData', disabled: true},
    {text: translate('deleteUser.voicemails'), value: 'voicemails', disabled: true},
    {text: translate('deleteUser.voicemailsGreetings'), value: 'voicemailsGreetings', disabled: true},
    {text: translate('deleteUser.calls'), value: 'calls', disabled: true},
    {text: translate('deleteUser.chatHistory'), value: 'chatHistory', disabled: true},
    {text: translate('deleteUser.phonebooks'), value: 'phonebooks', disabled: true},
    {text: translate('deleteUser.callGroupMember'), value: 'callGroupMember', disabled: true},
    {text: translate('deleteUser.missedCallManager'), value: 'missedCallManager', disabled: true},
    {text: translate('deleteUser.pagingGroupMember'), value: 'pagingGroupMember', disabled: true},
    {text: translate('deleteUser.applications'), value: 'applications', disabled: true},
    {text: translate('deleteUser.unassignDevices'), value: 'devices', disabled: true}
];
