export default function (blocker, table, excludeColumns) {
    const MINIMAL_COLUMN_WIDTH = 20;
    const CLASS_NAME_SIZE_CHANGER = 'column-size-changer';

    let movingTh;

    const init = () => {
        if (!table.querySelectorAll('.' + CLASS_NAME_SIZE_CHANGER).length) {
            table.addEventListener('mousemove', mouseMove);
            table.addEventListener('mouseup', mouseUp);
        }

        table.style.tableLayout = 'fixed';
        table.style.width = `${table.offsetWidth}px`;
        table.style.margin = 'inherit';

        const columns = [...table.querySelectorAll('th')];
        columns.forEach((th, index) => {
            th.style.position = 'relative';
            th.style.width = `${th.offsetWidth}px`;
            th.style.maxWidth = 'none';

            if (isNeedSkip(th, index, columns.length)) {
                return;
            }

            th.appendChild(makeSizeChanger(th));
        });
    };

    const isNeedSkip = (th, index, columnsLength) => {
        const isLastItem = (index + 1) >= columnsLength;
        const doesHaveSizeChanger = Boolean(th.querySelector('.' + CLASS_NAME_SIZE_CHANGER));
        const isExcludeColumn = excludeColumns.includes(index + 2) || excludeColumns.includes(index + 1);

        return isLastItem || doesHaveSizeChanger || isExcludeColumn;
    };

    const cutPx = str => Number(str.replace('px', ''));

    const cursorStyleToggle = (state = true) => {
        document.body.style.cursor = state ? 'col-resize' : '';
        document.body.style.userSelect = state ? 'none' : '';
    };

    const mouseMove = e => {
        if (blocker.state) {
            const thWidth = cutPx(movingTh.style.width);
            const tableWidth = cutPx(table.style.width);

            if ((thWidth + e.movementX) < MINIMAL_COLUMN_WIDTH) {
                return;
            }

            if (thWidth >= MINIMAL_COLUMN_WIDTH) {
                table.style.width = `${tableWidth + e.movementX}px`;
                movingTh.style.width = `${thWidth + e.movementX}px`;
            }

        }
    };

    const mouseUp = () => {
        if (!blocker.state) return;

        cursorStyleToggle(false);

        setTimeout(() => {
            blocker.state = false;
        }, 0);
    };

    const mouseDown = th => {
        movingTh = th;
        blocker.state = true;

        cursorStyleToggle();
    };

    const makeSizeChanger = th => {
        const sizeChanger = document.createElement('div');

        sizeChanger.style.position = 'absolute';
        sizeChanger.style.top = 0;
        sizeChanger.style.right = '-3px';
        sizeChanger.style.width = '5px';
        sizeChanger.style.cursor = 'col-resize';
        sizeChanger.style.zIndex = 1;
        sizeChanger.className = CLASS_NAME_SIZE_CHANGER;

        sizeChanger.addEventListener('mousedown', () => mouseDown(th));

        return sizeChanger;
    };

    setTimeout(() => init(), 0);
}
